#!/bin/bash
#######################################################################################################################
# Variables that are required to define the test case
EXPID="eg000"
ICON_CASE="event-generator"
ICON_VERSION="2.6.5-nwp0"
PLATFORM="REMOTE"
EXTRA_NAMELIST=""


# Few extra parameters that will be used to create some additional configuration
REMOTE_HOST=autosubmit_remote
REMOTE_USER=$USER
PROJECT="ls-craig"
PLATFORM_SCRATCH=$SCRATCH/autosubmit_rundir/

# We can provide an extra configuration file for autosubmit through this variable:
EXTRA_CONFIGURATION=$(
  cat <<-END
Platforms:
  REMOTE:
    TYPE: slurm
    HOST: "$REMOTE_HOST"
    PROJECT: "$PROJECT"
    USER: "$USER"
    SCRATCH_DIR: "$PLATFORM_SCRATCH"
    ADD_PROJECT_TO_HOST: False
    MAX_WALLCLOCK: '48:00'
    TEMP_DIR: ''
    CUSTOM_DIRECTIVES: "#SBATCH --export=ALL,OMPI_MCA_btl_tcp_if_include=10.0.0.0/8"

  REMOTE_LOGIN:
    TYPE: ps
    HOST: "$REMOTE_HOST"
    PROJECT: "$PROJECT"
    USER: "$USER"
    SCRATCH_DIR: "$PLATFORM_SCRATCH"
    ADD_PROJECT_TO_HOST: False
    MAX_WALLCLOCK: '48:00'
    TEMP_DIR: ''

Jobs:
  BUILD_ICON:
    PLATFORM: REMOTE_LOGIN
  BUILD_PYTHON_ENVIRONMENT:
    PLATFORM: REMOTE_LOGIN
END
)

# Trick to use a branch for testing
export PROJECT_BRANCH="event_generator"

#######################################################################################################################
set -euo pipefail

# Get path to the script directory
SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" >/dev/null 2>&1 && pwd)"

# Import the function run_autoicon_example
source ${SCRIPT_DIR}/example_utils.sh

# Setup and run the experiment
run_autoicon_example "$EXPID" "$ICON_CASE" "$ICON_VERSION" "$PLATFORM" "${EXTRA_NAMELIST}" "${EXTRA_CONFIGURATION}"
